@@ -24,10 +24,14 @@
 
 #include "settings.h"
 #include "callback.h"
+#include "menu.h"
 
 #include "dnd.h"
 
 
+/* mouse current position */
+gint mx, my;
+
 /* set user-defined terminal font */
 gboolean
 set_font (gchar *name, gchar *value, gpointer data, GError **error)
@@ -159,6 +163,12 @@ drop_data (GtkWidget *w, GdkDragContext *dc, gint x, gint y,
 gboolean
 popup_menu (GtkWidget *w, GdkEventButton *ev, gpointer data)
 {
+  GdkWindow *win;
+  
+  /* get mouse coordinates */
+  win = gtk_widget_get_parent_window (w);
+  gdk_window_get_pointer (win, &mx, &my, NULL);      
+
   if (ev->button == 3)
     {
       gtk_menu_popup ((GtkMenu *) data, NULL, NULL, NULL, NULL,
