@@ -16,3 +16,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+extern GtkWidget *term;
+
+GtkMenu *create_menu (gchar * filename);
